<?php

/* Customize Appearance Options */
function brnhmbx_customizeAppearance( $wp_customize ) {

	/* Custom Text Area Control in Customizer */
	class brnhmbx_customTextAreaControl extends WP_Customize_Control {

		public $type = 'textarea';

		public function render_content() { ?>
            <label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
            <div style="margin-bottom: 5px;"><em><?php echo esc_html( $this->description ); ?></em></div>
			<textarea rows="8" style="width: 100%; resize: none;" <?php esc_url( $this->link() ); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}

	}
	/* */

	/* Row Style Selectors */
	class brnhmbx_rowStyleSelector extends WP_Customize_Control {

		public $type = 'radio-image';

		public function render_content() { ?>

            <script type='text/javascript'>
                jQuery( document ).ready( function(a) {
                    a( '.brnhmbx-row-selector-outer label' ).click( function() {
                        a( this ).addClass( 'brnhmbx-row-selector-selected' ).siblings().removeClass( 'brnhmbx-row-selector-selected' );
                    });
                } );
            </script>

            <div id="<?php echo esc_attr( "input_{$this->id}" ); ?>" class="brnhmbx-row-selector-outer">
                <span class="row-label"><?php echo esc_html( $this->label ); ?></span><br />
                <span><?php echo esc_html( $this->description ); ?></span><br />
                <?php foreach ( $this->choices as $value => $args ) : ?>
				<input class="brnhmbx-row-selector-input" type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( "_customize-radio-{$this->id}" ); ?>" id="<?php echo esc_attr( "{$this->id}-{$value}" ); ?>" <?php $this->link(); ?> <?php checked( $this->value(), $value ); ?> />
                <label for="<?php echo esc_attr( "{$this->id}-{$value}" ); ?>"><img src="<?php echo esc_url( sprintf( $args['url'], get_template_directory_uri(), get_stylesheet_directory_uri() ) ); ?>" alt="<?php echo esc_attr( $args['label'] ); ?>" /></label>
				<?php endforeach; ?>
            </div>

		<?php }

		public function enqueue() {

			add_action( 'customize_controls_print_styles', array( $this, 'print_styles' ) );

		}

		public function print_styles() { ?>

			<style type="text/css">
                .brnhmbx-row-selector-outer span.row-label { font-weight: bold; font-size: 16px; }
                .brnhmbx-row-selector-outer label { display: inline-block; cursor: pointer; }
                .brnhmbx-row-selector-outer label { margin: 7px 5px 0px 0px; }
                .brnhmbx-row-selector-outer label img { border: 2px solid #EEE; }
                .brnhmbx-row-selector-input { position: absolute; left: -9999px; }
                .brnhmbx-row-selector-outer label.brnhmbx-row-selector-selected img { border: 2px solid #3c2313; }
				.brnhmbx-row-selector-outer input[type="radio"]:checked + label img { border: 2px solid #3c2313; }
            </style>

		<?php }

	}
	/* */

	function brnhmbx_sanitizer( $input ) {

		return $input;

	}

	////////////////////////////////////////////////////
	/*/////////////////// SECTIONS ///////////////////*/
	////////////////////////////////////////////////////

	$wp_customize->add_section( 'brnhmbx_sectionHome', array(
		'title' => __( 'Homepage Builder', '' ),
		'description' => '',
		'priority' => 1,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionWooCommerce', array(
		'title' => __( 'WooCommerce Settings', '' ),
		'description' => '',
		'priority' => 3,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionColors', array(
		'title' => __( 'Site Colors', '' ),
		'description' => '',
		'priority' => 5,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionFonts', array(
		'title' => __( 'Fonts', '' ),
		'description' => '',
		'priority' => 7,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionHeader', array(
		'title' => __( 'Header', '' ),
		'description' => '',
		'priority' => 10,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionSlider', array(
		'title' => __( 'Slider Settings', '' ),
		'description' => '',
		'priority' => 15,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionBlog', array(
		'title' => __( 'Blog Settings', '' ),
		'priority' => 20,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionShowHide', array(
		'title' => __( 'Show/Hide Blog Elements', '' ),
		'description' => '',
		'priority' => 25,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionFooter', array(
		'title' => __( 'Footer', '' ),
		'description' => '',
		'priority' => 30,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionGoogleMaps', array(
		'title' => __( 'Google Maps', '' ),
		'description' => '',
		'priority' => 35,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionTranslation', array(
		'title' => __( 'Translation', '' ),
		'description' => '',
		'priority' => 40,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionCSS', array(
		'title' => __( 'Custom CSS', '' ),
		'description' => 'Write your CSS code to override styles.',
		'priority' => 45,
	) );

	if ( !function_exists( 'wp_site_icon' ) ) {

		$wp_customize->add_section( 'brnhmbx_sectionFavicon', array(
			'title' => __( 'Favicon', '' ),
			'description' => '',
			'priority' => 50,
		) );

	}

	////////////////////////////////////////////////////
	/*/////////////////// SETTINGS ///////////////////*/
	////////////////////////////////////////////////////

	/* Homepage */
	$wp_customize->add_setting( 'brnhmbx_home_row_1', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_1', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_1', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_1', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_2', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_3', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_4', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_row_2', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_2', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_2', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_5', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_6', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_7', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_8', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_row_3', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_3', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_3', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_9', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_10', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_11', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_12', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_row_4', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_4', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_4', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_13', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_14', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_15', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_16', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_row_5', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_5', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_5', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_17', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_18', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_19', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_20', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_row_6', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_6', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_6', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_21', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_22', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_23', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_24', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_row_7', array( 'default' => '1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sh_row_7', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_bp_row_7', array( 'default' => 40, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_25', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_26', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_27', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_home_sc_28', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* WooCommerce Settings */
	$wp_customize->add_setting( 'brnhmbx_enableBFM', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_enableMagnifier', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_enableSingleProductImage', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_enableCatalogMode', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_catalogButtonText', array( 'default' => 'VIEW PRODUCT', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_productPerPage', array( 'default' => '9', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Layout_Product_Archive', array( 'default' => '3col_sidebar', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarProductDetail', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Colors */
	$wp_customize->add_setting( 'brnhmbx_color_Brown', array( 'default' => '#3c2313', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gray', array( 'default' => '#999', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_BorderGray', array( 'default' => '#e5e5e5', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Pink', array( 'default' => '#ce6ec2', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_LightBeige', array( 'default' => '#edeae3', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_DarkBeige', array( 'default' => '#dedacc', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Green', array( 'default' => '#789d74', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_DarkSomon', array( 'default' => '#c77f50', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Orange', array( 'default' => '#e89109', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Star', array( 'default' => '#d39f87', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_StarFaded', array( 'default' => '#e2ccbe', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Fonts */
	$wp_customize->add_setting( 'brnhmbx_font_Primary', array( 'default' => 'karla', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_font_Secondary', array( 'default' => 'arbutus', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Header */
	$wp_customize->add_setting( 'brnhmbx_text_Logo', array( 'default' => wp_title(), 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Logo', array( 'default' => '#3c2313', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_Logo', array( 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_logoPaddingBottom', array( 'default' => '0', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_logoPaddingTop', array( 'default' => '40', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_StickyLogo', array( 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_StickyLogo', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_stickyHeader', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_triggerSticky', array( 'default' => '600', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SpotMessages', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_spotMessages_1', array( 'default' => 'Free shipping on all orders over $100.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_spotMessages_2', array( 'default' => 'Big summer sale!', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_spotMessages_3', array( 'default' => 'We provide high quality products.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_MenuPos', array( 'default' => 'logo-top', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_HeaderMenu', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Slider */
	$wp_customize->add_setting( 'brnhmbx_sliderShortcode', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_SliderPosition', array( 'default' => 'cover', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Header', array( 'default' => '#e36d44', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_BBG', array( 'default' => '#77c9b1', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_BT', array( 'default' => '#FFF', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_Sli_Box', array( 'default' => '80', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderWidth', array( 'default' => '1160', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderHeight', array( 'default' => '600', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderHideMobile', array( 'default' => 'always', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Blog Settings */
	$wp_customize->add_setting( 'brnhmbx_blogTitle', array( 'default' => 'Shopping Tips', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_imageWidth', array( 'default' => '1160', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_imageHeight', array( 'default' => '0', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	// Post Formats
	$wp_customize->add_setting( 'brnhmbx_sh_FeaImg_Single_Standard', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Standard', array( 'default' => 'fea', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Gallery', array( 'default' => 'gal', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_GalleryPos_Gallery', array( 'default' => 'content', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Video', array( 'default' => 'gal', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Standard', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Standard_Archive', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Gallery', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Gallery_Archive', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Video', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Video_Archive', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Show/Hide Blog Elements */
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Standard', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Sidebar_Blog', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_RelatedPosts', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_PostComments', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_PageComments', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Date', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Hits', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Author', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Excerpt', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnReadMore', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnComments', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_TagBar', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_CategoryBar', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Footer */
	$wp_customize->add_setting( 'brnhmbx_text_Footer', array( 'default' => '© 2019 Grotte. All rights reserved.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_FooterMenu', array( 'default' => 1, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_footerWidgetsCol', array( 'default' => '4col', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_newsletterBarShortcode', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_newsletterBarLabel', array( 'default' => 'SUBSCRIBE TO OUR NEWSLETTER', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_newsletterBarSpan', array( 'default' => 'Type your e-mail address and click the button.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_newsletterBar', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Google Maps */
	$wp_customize->add_setting( 'brnhmbx_mapPage', array( 'sanitize_callback' => 'brnhmbx_returnMapPageID' ) );
	$wp_customize->add_setting( 'brnhmbx_coorN', array( 'default' => '49.0138', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_coorE', array( 'default' => '8.38624', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_MapZoom', array( 'default' => '15', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_mapHeight', array( 'default' => '500', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Map', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_enableMapKey', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_mapAPI', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_bxControls', array( 'default' => 'arrow', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_bxAuto', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_bxControls_Main', array( 'default' => 'arrow', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_bxAuto_Main', array( 'default' => 0, 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Translation */
	$wp_customize->add_setting( 'brnhmbx_tra_Lang', array( 'default' => ( get_bloginfo( 'language' ) ), 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_404', array( 'default' => 'Page not found', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Nothing', array( 'default' => 'Nothing found', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_SearchResults', array( 'default' => 'Search Results', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Page', array( 'default' => 'Page', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Tag', array( 'default' => 'Tag', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Category', array( 'default' => 'Category', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Author', array( 'default' => 'Author', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Archives', array( 'default' => 'Archives', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_NextPost', array( 'default' => 'NEXT', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_PrevPost', array( 'default' => 'PREVIOUS', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_By', array( 'default' => 'by', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_TypeKeyword', array( 'default' => 'Type keyword to search', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_ReadMore', array( 'default' => 'READ MORE', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_ViewAll', array( 'default' => 'VIEW ALL', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_ViewCount', array( 'default' => 'View', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_ViewsCount', array( 'default' => 'Views', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	// Post Comments
	$wp_customize->add_setting( 'brnhmbx_tra_Comment', array( 'default' => 'Comment', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Comments', array( 'default' => 'Comments', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Name', array( 'default' => 'Name', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Email', array( 'default' => 'E-mail', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Website', array( 'default' => 'Website', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_MustBeLogged', array( 'default' => 'You must be logged in to post a comment', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Logged', array( 'default' => 'Logged in', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LogOut', array( 'default' => 'Log out', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LeaveReply', array( 'default' => 'Leave a Reply', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_CancelReply', array( 'default' => 'Cancel Reply', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_PostComment', array( 'default' => 'POST COMMENT', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_At', array( 'default' => 'at', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Reply', array( 'default' => 'Reply', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Edit', array( 'default' => 'Edit', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Awaiting', array( 'default' => 'Comment awaiting approval', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	// Teasers
	$wp_customize->add_setting( 'brnhmbx_tra_Teaser_RelatedProducts', array( 'default' => 'This is an optional text for a tiny explanation about related products.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Teaser_Upsells', array( 'default' => 'This is an optional text for a tiny explanation about up-sell products.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Teaser_Crosssells', array( 'default' => 'This is an optional text for a tiny explanation about cross-sell products.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Teaser_RelatedPosts', array( 'default' => 'This is an optional text. Do not miss the ones below!', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Teaser_Comments', array( 'default' => 'This is an optional text. Share your comments and win surprise gifts!', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	// Buy For Me
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Header', array( 'default' => 'BUY FOR ME', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Preview', array( 'default' => 'E-mail Preview', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Design', array( 'default' => 'Design Options', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Color', array( 'default' => 'Color Scheme', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Button', array( 'default' => 'Button Text', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Message', array( 'default' => 'Your Message', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Price', array( 'default' => 'Hide Price', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Settings', array( 'default' => 'E-mail Settings', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Name', array( 'default' => 'Your Name', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Email', array( 'default' => 'Your E-mail Address', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Subject', array( 'default' => 'E-mail Subject', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Receiver', array( 'default' => 'Receiver E-mail Address', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Copy', array( 'default' => 'Send me a copy of this e-mail', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Send', array( 'default' => 'SEND E-MAIL', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Sent', array( 'default' => 'Your e-mail has been sent!', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_Problem', array( 'default' => 'A problem has occured. Please try again.', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_PH_Message', array( 'default' => 'Would you please buy this awesome piece for me dear? :)', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_PH_Button', array( 'default' => 'SHOP NOW', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BFM_PH_Subject', array( 'default' => 'I can forgive you if you buy this :)', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	// Menu Item Badges
	$wp_customize->add_setting( 'brnhmbx_tra_NEW', array( 'default' => 'NEW', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_HOT', array( 'default' => 'HOT', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_SALE', array( 'default' => 'SALE', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Custom CSS */
	$wp_customize->add_setting( 'brnhmbx_text_CSS', array( 'default' => '', 'sanitize_callback' => 'brnhmbx_sanitizer' ) );
	/* */

	/* Favicon */
	if ( !function_exists( 'wp_site_icon' ) ) {

		$wp_customize->add_setting( 'brnhmbx_upload_Favicon', array( 'sanitize_callback' => 'brnhmbx_sanitizer' ) );

	}
	/* */

	////////////////////////////////////////////////////
	/*/////////////////// CONTROLS ///////////////////*/
	////////////////////////////////////////////////////

	/* Homepage */
	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_1', array(
		'label' => __( 'ROW 1 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_1',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_1', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_1',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_1', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_1',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_1', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_1',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_2', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_2',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_3', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_3',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_4', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_4',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );

	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_2', array(
		'label' => __( 'ROW 2 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_2',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_2', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_2',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_2', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_2',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_5', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_5',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_6', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_6',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_7', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_7',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_8', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_8',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );

	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_3', array(
		'label' => __( 'ROW 3 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_3',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_3', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_3',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_3', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_3',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_9', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_9',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_10', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_10',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_11', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_11',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_12', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_12',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );

	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_4', array(
		'label' => __( 'ROW 4 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_4',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_4', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_4',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_4', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_4',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_13', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_13',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_14', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_14',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_15', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_15',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_16', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_16',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );

	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_5', array(
		'label' => __( 'ROW 5 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_5',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_5', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_5',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_5', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_5',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_17', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_17',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_18', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_18',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_19', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_19',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_20', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_20',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );

	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_6', array(
		'label' => __( 'ROW 6 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_6',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_6', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_6',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_6', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_6',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_21', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_21',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_22', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_22',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_23', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_23',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_24', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_24',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );

	$wp_customize->add_control( new brnhmbx_rowStyleSelector( $wp_customize, 'brnhmbx_home_row_7', array(
		'label' => __( 'ROW 7 Layout & Shortcodes', '' ),
		'description' => __( 'Choose a layout for this row and place your shortcodes into the fields.', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_row_7',
		'choices' => array(
			'1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1.png', 'label' => '1 Column' ),
			'2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2.png', 'label' => '2 Columns' ),
			'3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3.png', 'label' => '3 Columns' ),
			'4' => array( 'url' => get_template_directory_uri() . '/css/images/rl_4.png', 'label' => '4 Columns' ),
			'1_3' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_3.png', 'label' => '1 + 3 Columns' ),
			'3_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_3_1.png', 'label' => '3 + 1 Columns' ),
			'1_1_2' => array( 'url' => get_template_directory_uri() . '/css/images/rl_1_1_2.png', 'label' => '1 + 1 + 2 Columns' ),
			'2_1_1' => array( 'url' => get_template_directory_uri() . '/css/images/rl_2_1_1.png', 'label' => '2 + 1 + 1 Columns' ),
		)
    ) ) );

	$wp_customize->add_control( 'brnhmbx_home_sh_row_7', array(
		'label' => __( 'Hide This Row', '' ),
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sh_row_7',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_bp_row_7', array(
        'label' => __( '', '' ),
		'description' => 'Bottom Padding (Default value is "40".)',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_bp_row_7',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 50px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_25', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 1:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_25',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_26', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 2:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_26',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_27', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 3:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_27',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_home_sc_28', array(
        'label' => __( '', '' ),
		'description' => 'Shortcode for COLUMN 4:',
        'section' => 'brnhmbx_sectionHome',
        'settings' => 'brnhmbx_home_sc_28',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 40px;',
		),
    ) );
	/* */

	/* WooCommerce Settings */
	$wp_customize->add_control( 'brnhmbx_productPerPage', array(
        'label' => __( 'Number of Products per Page', '' ),
		'description' => 'Default value is "9".',
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_productPerPage',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_Layout_Product_Archive', array(
		'label' => __( 'Shop Layout', '' ),
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_opt_Layout_Product_Archive',
		'type' => 'radio',
		'choices' => array(
			'2col' => '2 Columns',
			'2col_sidebar' => '2 Columns + Sidebar',
			'3col' => '3 Columns',
			'3col_sidebar' => '3 Columns + Sidebar',
			'4col' => '4 Columns',
			'4col_sidebar' => '4 Columns + Sidebar',
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarProductDetail', array(
		'label' => __( 'Show Sidebar on Product Detail Page', '' ),
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_sh_SidebarProductDetail',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_enableBFM', array(
        'label' => __( 'Enable "Buy For Me"', '' ),
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_enableBFM',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_enableMagnifier', array(
        'label' => __( 'Enable Magnifier on Product Detail', '' ),
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_enableMagnifier',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_enableSingleProductImage', array(
        'label' => __( 'Enable Single Product Image', '' ),
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_enableSingleProductImage',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_enableCatalogMode', array(
        'label' => __( 'Enable Catalog Mode', '' ),
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_enableCatalogMode',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_catalogButtonText', array(
        'label' => __( 'Catalog Item Button Text', '' ),
		'description' => 'Write the text you want to see on the button instead of "Add to Cart". Only used if "Enable Catalog Mode" is checked.',
        'section' => 'brnhmbx_sectionWooCommerce',
        'settings' => 'brnhmbx_catalogButtonText',
		'type' => 'text'
    ) );
	/* */

	/* Colors */
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Brown', array(
        'label' => __( 'Primary', '' ), 'description' => 'Headers, Links, Main Buttons etc.', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Brown'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gray', array(
        'label' => __( 'Content', '' ), 'description' => 'Texts, Secondary Links etc.', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Gray'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_BorderGray', array(
        'label' => __( 'Borders & Lines', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_BorderGray'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Pink', array(
        'label' => __( 'Menu Item Hover', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Pink'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_LightBeige', array(
        'label' => __( 'Light Background', '' ), 'description' => 'Widget Backgrounds, Footer Background, Tab Background etc.', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_LightBeige'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_DarkBeige', array(
        'label' => __( 'Dark Background', '' ), 'description' => 'Secondary Buttons, Active Tab Items etc.', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_DarkBeige'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Green', array(
        'label' => __( 'Quick View Button', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Green'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_DarkSomon', array(
        'label' => __( 'Wishlist Button', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_DarkSomon'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Orange', array(
        'label' => __( 'Buy For Me Button', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Orange'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Star', array(
        'label' => __( 'Product Comments Star', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Star'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_StarFaded', array(
        'label' => __( 'Product Comments Faded Star', '' ), 'description' => '', 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_StarFaded'
	) ) );
	/* */

	/* Fonts */
	$wp_customize->add_control( 'brnhmbx_font_Primary', array(
		'label' => __( 'Primary Font', '' ),
        'section' => 'brnhmbx_sectionFonts',
		'description' => 'Menu items, content, button texts etc.',
        'settings' => 'brnhmbx_font_Primary',
		'type' => 'radio',
		'choices' => array(
			'karla' => 'Karla',
			'dosis' => 'Dosis',
			'josefin' => 'Josefin Sans',
			'raleway' => 'Raleway',
			'andada' => 'Andada',
			'roboto' => 'Roboto',
			'arbutus' => 'Arbutus Slab',
			'open-sans' => 'Open Sans',
			'droid-serif' => 'Droid Serif',
			'ubuntu' => 'Ubuntu',
			'hind' => 'Hind',
			'oxygen' => 'Oxygen'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_font_Secondary', array(
		'label' => __( 'Secondary Font', '' ),
        'section' => 'brnhmbx_sectionFonts',
		'description' => 'Page header and some other headers.',
        'settings' => 'brnhmbx_font_Secondary',
		'type' => 'radio',
		'choices' => array(
			'karla' => 'Karla',
			'dosis' => 'Dosis',
			'josefin' => 'Josefin Sans',
			'raleway' => 'Raleway',
			'andada' => 'Andada',
			'roboto' => 'Roboto',
			'arbutus' => 'Arbutus Slab',
			'open-sans' => 'Open Sans',
			'droid-serif' => 'Droid Serif',
			'ubuntu' => 'Ubuntu',
			'hind' => 'Hind',
			'oxygen' => 'Oxygen'
		)
    ) );
	/* */

	/* Header */
	$wp_customize->add_control( 'brnhmbx_text_Logo', array(
        'label' => __( 'Logo Text', '' ),
		'description' => 'Leave blank if you want to use the "Site Title". If a logo image is uploaded, this will never be shown.',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_text_Logo',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Logo', array(
        'label' => __( 'Logo Text Color', '' ), 'description' => '', 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_Logo'
	) ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Logo', array(
				'label' => 'Logo Image',
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_Logo'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_opt_MenuPos', array(
        'label' => __( 'Logo Position', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_opt_MenuPos',
		'type' => 'radio',
		'choices' => array(
			'logo-top' => 'Top',
			'logo-left' => 'Left'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_logoPaddingTop', array(
        'label' => __( 'Logo Top Padding', '' ),
		'description' => 'Only used if "Logo Position" is "Top".',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_logoPaddingTop',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_logoPaddingBottom', array(
        'label' => __( 'Logo Bottom Padding', '' ),
		'description' => 'Only used if "Logo Position" is "Top".',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_logoPaddingBottom',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_StickyLogo', array(
				'label' => 'Sticky Logo Image',
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_StickyLogo'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_sh_StickyLogo', array(
        'label' => __( 'Show Sticky Logo', '' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_sh_StickyLogo',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_stickyHeader', array(
        'label' => __( 'Sticky Header', '' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_stickyHeader',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_triggerSticky', array(
        'label' => __( '', '' ),
		'description' => 'Trigger sticky header when scroll position is higher than:',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_triggerSticky',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_HeaderMenu', array(
        'label' => __( 'Show Header Menu', '' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_sh_HeaderMenu',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SpotMessages', array(
        'label' => __( 'Show Spot Messages', '' ),
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_sh_SpotMessages',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_spotMessages_1', array(
        'label' => __( 'Spot Message 1', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_spotMessages_1',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_spotMessages_2', array(
        'label' => __( 'Spot Message 2', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_spotMessages_2',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_spotMessages_3', array(
        'label' => __( 'Spot Message 3', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionHeader',
        'settings' => 'brnhmbx_spotMessages_3',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );
	/* */

	/* Slider */
	$wp_customize->add_control( 'brnhmbx_sliderShortcode', array(
        'label' => __( 'Slider Shortcode', '' ),
		'description' => 'Example usages:<br>Old Slider:<br>[grotte_slider group="your_group"]<br>New Slider:<br>[new_grotte_slider group="your_group"]<br>You can also use any other slider shortcode here.',
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderShortcode',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_SliderPosition', array(
        'label' => __( 'Style', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_SliderPosition',
		'type' => 'radio',
		'choices' => array(
			'full' => 'Fullwidth',
			'cover' => 'Cover'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_bxControls_Main', array(
		'label' => __( 'Control Settings', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_bxControls_Main',
		'type' => 'radio',
		'choices' => array(
			'arrow' => 'Show Prev/Next Arrows',
			'none' => 'None'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_bxAuto_Main', array(
		'label' => __( 'Autoplay Slides', '' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bxAuto_Main',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderWidth', array(
        'label' => __( 'Slide Image Width', '' ),
		'description' => 'Default value is "1160".<br>Since the slider is responsive, display results may seem different. If you want to use "Fullwidth" option for instance, to set it 2560 and upload big images make sense.<br>Works for only new added images.',
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderWidth',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderHeight', array(
        'label' => __( 'Slide Image Height', '' ),
		'description' => 'Default value is "600".<br>This value is fixed, not responsive.<br>Works for only new added images.',
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderHideMobile', array(
		'label' => __( 'Mobile Settings', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderHideMobile',
		'type' => 'radio',
		'choices' => array(
			'always' => 'Always Show',
			'320' => 'Hide at 320px',
			'480' => 'Hide at 480px',
			'640' => 'Hide at 640px'
		)
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Header', array(
        'label' => __( 'Header Color', '' ), 'description' => '', 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Header'
	) ) );

	$wp_customize->add_control( 'brnhmbx_rng_Sli_Box', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionSlider',
		'label'       => 'Header Opacity',
		'description' => '',
		'input_attrs' => array(
			'min'   => 0,
			'max'   => 100,
			'step'  => 10
		)
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_BBG', array(
        'label' => __( 'Button Background Color', '' ), 'description' => '', 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_BBG'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_BT', array(
        'label' => __( 'Button Text Color', '' ), 'description' => '', 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_BT'
	) ) );
	/* */

	/* Blog Settings */
	$wp_customize->add_control( 'brnhmbx_blogTitle', array(
        'label' => __( 'Blog Page Header', '' ),
		'description' => 'Original: "Shopping Tips"',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_blogTitle',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_imageWidth', array(
        'label' => __( 'Featured Image Width', '' ),
		'description' => 'Default value is "1160".<br>Write "0" to not to resize the images.<br>Works for only new added ones.',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_imageWidth',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_imageHeight', array(
        'label' => __( 'Featured Image Height', '' ),
		'description' => 'Default value is "0".<br>Write "0" to not to crop the images.<br>Works for only new added ones.',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_imageHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Standard', array(
		'label' => __( 'Show Sidebar on Blog Post Pages', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_sh_SidebarPost_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Sidebar_Blog', array(
		'label' => __( 'Show Sidebar on Blog Page', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_sh_Sidebar_Blog',
		'type' => 'checkbox',
    ) );
	// Post Formats
	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Standard', array(
        'label' => __( 'Standard Posts', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_opt_FeaImg_Standard',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_FeaImg_Single_Standard', array(
		'label' => __( 'Show Featured Image on Post Pages', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_sh_FeaImg_Single_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Standard', array(
		'label' => __( 'Show full post on Homepage', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_ignoreExcerpt_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Standard_Archive', array(
		'label' => __( 'Show full post on Archive Pages', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_ignoreExcerpt_Standard_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Gallery', array(
        'label' => __( 'Gallery Posts', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_opt_FeaImg_Gallery',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'gal' => 'Show gallery image(s)',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Gallery', array(
		'label' => __( 'Show full post on Homepage', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_ignoreExcerpt_Gallery',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Gallery_Archive', array(
		'label' => __( 'Show full post on Archive Pages', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_ignoreExcerpt_Gallery_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_GalleryPos_Gallery', array(
        'label' => __( 'Gallery Position', '' ),
		'description' => 'Choose the gallery position on post page.',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_opt_GalleryPos_Gallery',
		'type' => 'radio',
		'choices' => array(
			'content' => 'Only in Content',
			'iof' => 'Instead of Featured Image',
			'both' => 'Both'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_bxControls', array(
		'label' => __( 'Gallery Slider Settings', '' ),
		'description' => 'Video sliders will use these settings too.',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_opt_bxControls',
		'type' => 'radio',
		'choices' => array(
			'arrow' => 'Show Prev/Next Arrows',
			'none' => 'None'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_bxAuto', array(
		'label' => __( 'Autoplay Slides', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_bxAuto',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Video', array(
        'label' => __( 'Video Posts', '' ),
		'description' => '',
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_opt_FeaImg_Video',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'gal' => 'Show video(s)',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Video', array(
		'label' => __( 'Show full post on Homepage', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_ignoreExcerpt_Video',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Video_Archive', array(
		'label' => __( 'Show full post on Archive Pages', '' ),
        'section' => 'brnhmbx_sectionBlog',
        'settings' => 'brnhmbx_ignoreExcerpt_Video_Archive',
		'type' => 'checkbox',
    ) );
	/* */

	/* Show/Hide Blog Elements */
	$wp_customize->add_control( 'brnhmbx_sh_RelatedPosts', array(
		'label' => __( 'Show Related Posts', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_RelatedPosts',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_PostComments', array(
		'label' => __( 'Show Post Comments', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_PostComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_PageComments', array(
		'label' => __( 'Show Page Comments', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_PageComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Date', array(
		'label' => __( 'Show Date', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Date',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnComments', array(
		'label' => __( 'Show Comments Icon', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Hits', array(
		'label' => __( 'Show Hit Counter', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Hits',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Excerpt', array(
		'label' => __( 'Show Excerpt', '' ),
		'description' => __( '', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Excerpt',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_TagBar', array(
		'label' => __( 'Show Tags', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_TagBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_CategoryBar', array(
		'label' => __( 'Show Categories', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_CategoryBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnReadMore', array(
		'label' => __( 'Show Read More Button', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnReadMore',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Author', array(
		'label' => __( 'Show Author', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Author',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SocialBar', array(
		'label' => __( 'Show Share Icons', '' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar',
		'type' => 'checkbox',
    ) );
	/* */

	/* Footer */
	$wp_customize->add_control( 'brnhmbx_text_Footer', array(
        'label' => __( 'Copyright Text', '' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_text_Footer',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_FooterMenu', array(
        'label' => __( 'Show Footer Menu', '' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_sh_FooterMenu',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_footerWidgetsCol', array(
		'label' => __( 'Widget Columns', '' ),
        'section' => 'brnhmbx_sectionFooter',
		'description' => '',
        'settings' => 'brnhmbx_footerWidgetsCol',
		'type' => 'radio',
		'choices' => array(
			'2col' => '2 Columns',
			'3col' => '3 Columns',
			'4col' => '4 Columns'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_newsletterBarShortcode', array(
        'label' => __( 'Newsletter Bar Shortcode', '' ),
		'description' => __( '<a href="https://wordpress.org/plugins/mailchimp-for-wp/" target="_blank">MailChimp for WordPress Lite</a> plugin must be installed and activated.', '' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_newsletterBarShortcode',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_newsletterBarLabel', array(
        'label' => __( 'Newsletter Bar Label', '' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_newsletterBarLabel',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_newsletterBarSpan', array(
        'label' => __( 'Newsletter Bar Explanation', '' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_newsletterBarSpan',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_newsletterBar', array(
        'label' => __( 'Show Newsletter Bar', '' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_sh_newsletterBar',
		'type' => 'checkbox'
    ) );
	/* */

	/* Google Maps */
	$wp_customize->add_control( 'brnhmbx_mapPage', array(
        'label' => __( 'Choose a Page', '' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_mapPage',
		 'type' => 'dropdown-pages',
    ) );

	$wp_customize->add_control( 'brnhmbx_coorN', array(
        'label' => __( 'Coordinate N', '' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_coorN',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_coorE', array(
        'label' => __( 'Coordinate E', '' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_coorE',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_rng_MapZoom', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionGoogleMaps',
		'label'       => 'Zoom Level',
		'description' => '',
		'input_attrs' => array(
			'min'   => 5,
			'max'   => 19,
			'step'  => 1
		)
	) );

	$wp_customize->add_control( 'brnhmbx_mapHeight', array(
        'label' => __( 'Map Height', '' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_mapHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Map', array(
        'label' => __( 'Show Map', '' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_sh_Map',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_enableMapKey', array(
		'label' => __( 'Enable Map API Key', '' ),
		'section' => 'brnhmbx_sectionGoogleMaps',
		'settings' => 'brnhmbx_enableMapKey',
		'type' => 'checkbox',
	) );
	$wp_customize->add_control( 'brnhmbx_mapAPI', array(
		'label' => __( 'API Key', '' ),
		'description' => 'Only used if "Enable Map API Key" is checked.',
		'section' => 'brnhmbx_sectionGoogleMaps',
		'settings' => 'brnhmbx_mapAPI',
		'type' => 'text',
	) );
	/* */

	/* Translation */
	$wp_customize->add_control( 'brnhmbx_tra_Lang', array(
        'label' => __( 'Site Language', '' ),
		'description' => 'Original: "' . esc_html( get_bloginfo( 'language' ) ) . '"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Lang',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_404', array(
        'label' => __( 'Wording', '' ),
		'description' => 'Original: "Page not found"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_404',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Nothing', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Nothing found"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Nothing',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_SearchResults', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Search Results"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_SearchResults',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Page', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Page"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Page',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Tag', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Tag"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Tag',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Category', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Category"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Category',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Author', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Author"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Author',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Archives', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Archives"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Archives',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_NextPost', array(
        'label' => __( '', '' ),
		'description' => 'Original: "NEXT"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NextPost',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_PrevPost', array(
        'label' => __( '', '' ),
		'description' => 'Original: "PREVIOUS"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_PrevPost',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_By', array(
        'label' => __( '', '' ),
		'description' => 'Original: "by"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_By',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_TypeKeyword', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Type keyword to search"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_TypeKeyword',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_ReadMore', array(
        'label' => __( '', '' ),
		'description' => 'Original: "READ MORE"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_ReadMore',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_ViewAll', array(
        'label' => __( '', '' ),
		'description' => 'Original: "VIEW ALL"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_ViewAll',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_ViewCount', array(
        'label' => __( '', '' ),
		'description' => 'Original: "View"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_ViewCount',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_ViewsCount', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Views"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_ViewsCount',
		'type' => 'text',
    ) );
	// Post Comments
	$wp_customize->add_control( 'brnhmbx_tra_Comment', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Comment"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Comment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Comments', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Comments"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Comments',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Name', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Name"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Name',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Email', array(
        'label' => __( '', '' ),
		'description' => 'Original: "E-mail"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Email',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Website', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Website"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Website',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_MustBeLogged', array(
        'label' => __( '', '' ),
		'description' => 'Original: "You must be logged in to post a comment"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_MustBeLogged',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Logged', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Logged in"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Logged',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_LogOut', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Log out"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_LogOut',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_LeaveReply', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Leave a Reply"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_LeaveReply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_CancelReply', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Cancel Reply"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_CancelReply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_PostComment', array(
        'label' => __( '', '' ),
		'description' => 'Original: "POST COMMENT"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_PostComment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_At', array(
        'label' => __( '', '' ),
		'description' => 'Original: "at"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_At',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Reply', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Reply"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Reply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Edit', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Edit"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Edit',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Awaiting', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Comment awaiting approval"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Awaiting',
		'type' => 'text',
    ) );
	// Teasers
	$wp_customize->add_control( 'brnhmbx_tra_Teaser_RelatedProducts', array(
        'label' => __( '', '' ),
		'description' => 'Original: "This is an optional text for a tiny explanation about related products."',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Teaser_RelatedProducts',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Teaser_Upsells', array(
        'label' => __( '', '' ),
		'description' => 'Original: "This is an optional text for a tiny explanation about up-sell products."',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Teaser_Upsells',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Teaser_Crosssells', array(
        'label' => __( '', '' ),
		'description' => 'Original: "This is an optional text for a tiny explanation about cross-sell products."',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Teaser_Crosssells',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Teaser_RelatedPosts', array(
        'label' => __( '', '' ),
		'description' => 'Original: "This is an optional text. Do not miss the ones below!"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Teaser_RelatedPosts',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Teaser_Comments', array(
        'label' => __( '', '' ),
		'description' => 'Original: "This is an optional text. Share your comments and win surprise gifts!"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Teaser_RelatedPosts',
		'type' => 'text',
    ) );
	// Buy For Me
	$wp_customize->add_control( 'brnhmbx_tra_BFM_Header', array(
        'label' => __( '', '' ),
		'description' => 'Original: "BUY FOR ME"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Header',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Preview', array(
        'label' => __( '', '' ),
		'description' => 'Original: "E-mail Preview"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Preview',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Design', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Design Options"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Design',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Color', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Color Scheme"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Color',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Button', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Button Text"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Button',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Message', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Your Message"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Message',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Price', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Hide Price"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Price',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Settings', array(
        'label' => __( '', '' ),
		'description' => 'Original: "E-mail Settings"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Settings',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Name', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Your Name"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Name',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Email', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Your E-mail Address"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Email',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Subject', array(
        'label' => __( '', '' ),
		'description' => 'Original: "E-mail Subject"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Subject',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Receiver', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Receiver E-mail Address"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Receiver',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Copy', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Send me a copy of this e-mail"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Copy',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Send', array(
        'label' => __( '', '' ),
		'description' => 'Original: "SEND E-MAIL"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Send',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Sent', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Your e-mail has been sent!"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Sent',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_Problem', array(
        'label' => __( '', '' ),
		'description' => 'Original: "A problem has occured. Please try again."',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_Problem',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_PH_Message', array(
        'label' => __( '', '' ),
		'description' => 'Original: "Would you please buy this awesome piece for me dear? :)"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_PH_Message',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_PH_Button', array(
        'label' => __( '', '' ),
		'description' => 'Original: "SHOP NOW"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_PH_Button',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BFM_PH_Subject', array(
        'label' => __( '', '' ),
		'description' => 'Original: "I can forgive you if you buy this :)"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BFM_PH_Subject',
		'type' => 'text',
    ) );
	// Menu Item Badges
	$wp_customize->add_control( 'brnhmbx_tra_NEW', array(
        'label' => __( '', '' ),
		'description' => 'Original: "NEW"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NEW',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_HOT', array(
        'label' => __( '', '' ),
		'description' => 'Original: "HOT"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_HOT',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_SALE', array(
        'label' => __( '', '' ),
		'description' => 'Original: "SALE"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_SALE',
		'type' => 'text',
    ) );
	/* */

	/* Custom CSS */
	$wp_customize->add_control( new brnhmbx_customTextAreaControl( $wp_customize, 'brnhmbx_text_CSS', array(
		'label' => __( '', '' ),
        'section' => 'brnhmbx_sectionCSS',
        'settings' => 'brnhmbx_text_CSS',
		'type' => 'text',
    ) ) );
	/* */

	/* Favicon */
	if ( !function_exists( 'wp_site_icon' ) ) {

		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Favicon', array(
					'label' => 'Upload Favicon',
					'description' => '',
					'section' => 'brnhmbx_sectionFavicon',
					'settings' => 'brnhmbx_upload_Favicon'
				)
			)
		);

	}
	/* */

	function brnhmbx_returnMapPageID( $input ) {

		if( is_numeric( $input ) ) {

			return intval( $input );

		}

	}
	/* */
}
add_action( 'customize_register', 'brnhmbx_customizeAppearance' );
?>
