<?php
/**
 * Cart Page
 *
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$brnhmbx_tra_Teaser_Crosssells = get_theme_mod( 'brnhmbx_tra_Teaser_Crosssells', 'This is an optional text for a tiny explanation about cross-sell products.' );

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>

<div class="cart-page-left-outer clearfix">
    <div class="cart-page-left-inner">

    <form action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">

    <?php do_action( 'woocommerce_before_cart_table' ); ?>

    <table class="shop_table cart" cellspacing="0">
        <thead>
            <tr>
                <th class="product-name"><span class="nobr"><?php esc_html_e( 'Product', 'woocommerce' ); ?></span></th>
                <th class="product-price"><span class="nobr"><?php esc_html_e( 'Price', 'woocommerce' ); ?></span></th>
                <th class="product-quantity"><span class="nobr"><?php esc_html_e( 'Quantity', 'woocommerce' ); ?></span></th>
                <th class="product-subtotal"><span class="nobr"><?php esc_html_e( 'Total', 'woocommerce' ); ?></span></th>
                <th class="product-remove">&nbsp;</th>
            </tr>
        </thead>
        <tbody>
            <?php do_action( 'woocommerce_before_cart_contents' ); ?>

            <?php
            foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                $_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                $product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                    ?>
                    <tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

                        <td class="product-name">
                            <div class="product-thumbnail">
                                <?php
                                    $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                    if ( ! $_product->is_visible() ) {
                                        echo $thumbnail;
                                    } else {
                                        printf( '<a href="%s">%s</a>', esc_url( $_product->get_permalink( $cart_item ) ), $thumbnail );
                                    }
                                ?>
                            </div>
                            <div class="product-date-added">
                            <?php
                                if ( ! $_product->is_visible() ) {
                                    echo apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;';
                                } else {
                                    echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s </a>', esc_url( $_product->get_permalink( $cart_item ) ), $_product->get_name() ), $cart_item, $cart_item_key );
                                }

                                // Meta data
																echo wc_get_formatted_cart_item_data( $cart_item );

                                // Backorder notification
                                if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                    echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'woocommerce' ) . '</p>';
                                }
                            ?>
                            </div>
                        </td>

                        <td class="product-price">
                            <?php
                                echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                            ?>
                        </td>

                        <td class="product-quantity">
                            <?php
                                if ( $_product->is_sold_individually() ) {
                                    $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                } else {
                                    $product_quantity = woocommerce_quantity_input( array(
                                        'input_name'  => "cart[{$cart_item_key}][qty]",
                                        'input_value' => $cart_item['quantity'],
                                        'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
                                        'min_value'   => '0'
                                    ), $_product, false );
                                }

                                echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key );
                            ?>
                        </td>

                        <td class="product-subtotal">
                            <?php
                                echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
                            ?>
                        </td>

                        <td class="product-remove">
                            <?php
							echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
								'<a href="%s" class="brnhmbx-remove" title="%s" data-product_id="%s" data-product_sku="%s"><i class="fa fa-times-circle"></i></a>',
								esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
								__( 'Remove this item', 'woocommerce' ),
								esc_attr( $product_id ),
								esc_attr( $_product->get_sku() )
							), $cart_item_key );
							?>
                        </td>
                    </tr>
                    <?php
                }
            } ?>

        </tbody>
    </table>

    <?php do_action( 'woocommerce_after_cart_table' ); ?>

    <div class="clearfix cart-coupon-update-bar">
    <?php do_action( 'woocommerce_cart_contents' );

        if ( WC()->cart->coupons_enabled() ) { ?>
            <div class="coupon">

                <label for="coupon_code"><?php esc_html_e( 'Coupon:', 'woocommerce' ); ?></label> <input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'woocommerce' ); ?>" /> <input type="submit" class="button brnhmbx-button-style-2" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'woocommerce' ); ?>" />

                <?php do_action( 'woocommerce_cart_coupon' ); ?>
            </div>
        <?php } ?>

        <input type="submit" class="button brnhmbx-button-style-2" name="update_cart" value="<?php esc_html_e( 'Update cart', 'woocommerce' ); ?>" />

        <?php do_action( 'woocommerce_cart_actions' ); ?>

        <?php wp_nonce_field( 'woocommerce-cart' ); ?>

        <?php do_action( 'woocommerce_after_cart_contents' ); ?>

    </div>

    </form>

    <?php

    $posts_per_page = 8;
    $columns = 2;

    global $product, $woocommerce_loop;

    $crosssells = WC()->cart->get_cross_sells();

    if ( sizeof( $crosssells ) > 0 ) {

		$meta_query = WC()->query->get_meta_query();

		$args = array(
			'post_type'           => 'product',
			'ignore_sticky_posts' => 1,
			'no_found_rows'       => 1,
			'posts_per_page'      => apply_filters( 'woocommerce_cross_sells_total', $posts_per_page ),
			'orderby'             => 'rand',
			'post__in'            => $crosssells,
			'meta_query'          => $meta_query
		);

		$products = new WP_Query( $args );

		$woocommerce_loop['columns'] = apply_filters( 'woocommerce_cross_sells_columns', $columns );

		if ( $products->have_posts() ) : ?>

			<div class="cross-sells">

				<h2><?php _e( 'You may be interested in&hellip;', 'woocommerce' ) ?></h2>
				<div class="brnhmbx-related-products-teaser"><?php echo esc_attr( $brnhmbx_tra_Teaser_Crosssells ); ?></div>

				<?php woocommerce_product_loop_start(); ?>

					<?php while ( $products->have_posts() ) : $products->the_post(); ?>

						<?php wc_get_template_part( 'content', 'product' ); ?>

					<?php endwhile; // end of the loop. ?>

				<?php woocommerce_product_loop_end(); ?>

			</div>

		<?php endif;

		wp_reset_query();

	}

    ?>

    </div>
</div>

<div class="cart-collaterals">

	<?php do_action( 'woocommerce_cart_collaterals' ); ?>

</div>

<?php do_action( 'woocommerce_after_cart' ); ?>
