<?php
/**
 * Review order table
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<table class="shop_table woocommerce-checkout-review-order-table">
	<thead>
		<tr>
			<th class="product-name"><span class="nobr"><?php _e( 'Product', 'woocommerce' ); ?></span></th>
			<th class="product-total"><span class="nobr"><?php _e( 'Total', 'woocommerce' ); ?></span></th>
		</tr>
	</thead>
	<tbody>
		<?php
			do_action( 'woocommerce_review_order_before_cart_contents' );

			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
				$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );

				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_checkout_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
					?>
					<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
						<td class="product-name">
							<?php echo apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;'; ?>
							<?php echo apply_filters( 'woocommerce_checkout_cart_item_quantity', ' <strong class="product-quantity">' . sprintf( '&times; %s', $cart_item['quantity'] ) . '</strong>', $cart_item, $cart_item_key ); ?>
							<?php echo wc_get_formatted_cart_item_data( $cart_item ); ?>
						</td>
						<td class="product-total">
							<?php echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); ?>
						</td>
					</tr>
					<?php
				}
			}

			do_action( 'woocommerce_review_order_after_cart_contents' );
		?>
	</tbody>
</table>

<div class="order-detail-summary-outer">

	<div class="cart-subtotal">
    	<h2><?php _e( 'Subtotal', 'woocommerce' ); ?></h2>
	    <div class="order-detail-summary-item"><?php wc_cart_totals_subtotal_html(); ?></div>
    </div>

    <?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
    	<div class="cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
	        <h2><?php wc_cart_totals_coupon_label( $coupon ); ?></h2>
    	    <div class="order-detail-summary-item"><?php wc_cart_totals_coupon_html( $coupon ); ?></div>
        </div>
    <?php endforeach; ?>

    <?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>

        <?php do_action( 'woocommerce_review_order_before_shipping' ); ?>

        <?php wc_cart_totals_shipping_html(); ?>

        <?php do_action( 'woocommerce_review_order_after_shipping' ); ?>

    <?php endif; ?>

    <?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
	    <div class="fee">
    	    <h2><?php echo esc_html( $fee->name ); ?></h2>
	        <div class="order-detail-summary-item"><?php wc_cart_totals_fee_html( $fee ); ?></div>
        </div>
    <?php endforeach; ?>

		<?php if ( wc_tax_enabled() && ! WC()->cart->display_prices_including_tax() ) : ?>
        <?php if ( get_option( 'woocommerce_tax_total_display' ) === 'itemized' ) : ?>
            <?php foreach ( WC()->cart->get_tax_totals() as $code => $tax ) : ?>
	            <div class="tax-rate tax-rate-<?php echo sanitize_title( $code ); ?>">
    	            <h2><?php echo esc_html( $tax->label ); ?></h2>
        	        <div class="order-detail-summary-item"><?php echo wp_kses_post( $tax->formatted_amount ); ?></div>
                </div>
            <?php endforeach; ?>
        <?php else : ?>
	        <div class="tax-total">
	            <h2><?php echo esc_html( WC()->countries->tax_or_vat() ); ?></h2>
    	        <div class="order-detail-summary-item"><?php echo wc_price( WC()->cart->get_taxes_total() ); ?></div>
            </div>
        <?php endif; ?>
    <?php endif; ?>

    <?php do_action( 'woocommerce_review_order_before_order_total' ); ?>

	<div class="order-total">
	    <h2><?php _e( 'Total', 'woocommerce' ); ?></h2>
	    <div class="order-detail-summary-item"><?php wc_cart_totals_order_total_html(); ?></div>
    </div>

    <?php do_action( 'woocommerce_review_order_after_order_total' ); ?>

</div>
