<?php
/**
 * Grouped product add to cart
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $post;

$parent_product_post = $post;

do_action( 'woocommerce_before_add_to_cart_form' ); ?>

<form class="cart" method="post" enctype='multipart/form-data'>
	<table cellspacing="0" class="group_table">
		<tbody>
			<?php
				foreach ( $grouped_products as $product_id ) :
					$product = wc_get_product( $product_id );

					if ( 'yes' === get_option( 'woocommerce_hide_out_of_stock_items' ) && ! $product->is_in_stock() ) {
						continue;
					}

					$group_linked_image = $product->get_image( $size = 'shop_thumbnail' );

					$post    = get_post( $product->get_id() );
					setup_postdata( $post );
					?>
					<tr>
						<td>
							<?php if ( $product->is_sold_individually() || ! $product->is_purchasable() ) : ?>
								<?php woocommerce_template_loop_add_to_cart(); ?>
							<?php else : ?>
								<?php
									$quantites_required = true;
									/**
									 * @since 3.0.0.
									 */
									do_action( 'woocommerce_before_add_to_cart_quantity' );

									woocommerce_quantity_input( array(
										'input_name'  => 'quantity[' . $product_id->get_id() . ']',
										'input_value' => isset( $_POST['quantity'][ $product_id->get_id() ] ) ? wc_stock_amount( $_POST['quantity'][ $product_id->get_id() ] ) : 0,
										'min_value'   => apply_filters( 'woocommerce_quantity_input_min', 0, $product_id ),
										'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product_id->get_max_purchase_quantity(), $product_id ),
									) );

									/**
									 * @since 3.0.0.
									 */
									do_action( 'woocommerce_after_add_to_cart_quantity' );
								?>
							<?php endif; ?>
						</td>

						<td class="label">
							<label for="product-<?php echo $product_id; ?>">
								<?php echo $product->is_visible() ? '<a href="' . esc_url( apply_filters( 'woocommerce_grouped_product_list_link', get_permalink(), $product_id ) ) . '">' . $group_linked_image . esc_html( get_the_title() ) . '</a>' : esc_html( get_the_title() ); ?>
							</label>
						</td>

						<?php do_action ( 'woocommerce_grouped_product_list_before_price', $product ); ?>

						<td class="price">
							<?php
								echo $product->get_price_html();

								if ( $availability = $product->get_availability() ) {
									$availability_html = empty( $availability['availability'] ) ? '' : '<br /><span style="font-size: 13px;" class="stock ' . esc_attr( $availability['class'] ) . '">' . esc_html( $availability['availability'] ) . '</span>';
									echo apply_filters( 'woocommerce_stock_html', $availability_html, $availability['availability'], $product );
								}
							?>
						</td>
					</tr>
					<?php
				endforeach;

				// Reset to parent grouped product
				$post    = $parent_product_post;
				$product = wc_get_product( $parent_product_post->ID );
				setup_postdata( $parent_product_post );
			?>
		</tbody>
	</table>

	<input type="hidden" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" />

	<?php if ( $quantites_required ) : ?>

		<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

        <?php if ( !get_theme_mod( 'brnhmbx_enableCatalogMode', 0 ) ) { ?><button type="submit" class="single_add_to_cart_button button alt clearfix brnhmbx-button b170"><span><?php echo $product->single_add_to_cart_text(); ?></span></button><?php } ?>
        <?php if ( shortcode_exists( 'yith_wcwl_add_to_wishlist' ) || get_theme_mod( 'brnhmbx_enableBFM', 1 ) ) { ?><div class="wish-bfm-outer clearfix"><?php if ( shortcode_exists( 'yith_wcwl_add_to_wishlist' ) ) { echo '<div class="wish-outer">' . do_shortcode( '[yith_wcwl_add_to_wishlist]' ) . '</div>'; } ?>
		<?php if ( get_theme_mod( 'brnhmbx_enableBFM', 1 ) ) { ?><div class="brnhmbx-button b170 clearfix ico-gift brnhmbx-bfm"><div><?php echo esc_attr( get_theme_mod( 'brnhmbx_tra_BFM_Header', 'BUY FOR ME' ) ); ?></div><i class="fa fa-gift"></i></div><?php } ?></div><?php } ?>

		<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>

	<?php endif; ?>
</form>

<?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>
